@@ -136,7 +136,8 @@ def write_results(filename, results):
                     s=round(score, 2),
                 )
                 f.write(line)
-    logger.info("save results to {}".format(filename))
+    logger.info(f"save results to {filename}")
+    logger.info(f"length of results: {len(results)}")
 
 
 class Predictor(object):
@@ -337,6 +338,7 @@ def imageflow_demo(predictor, vis_folder, current_time, args, exp):
         else:
             break
         frame_id += 1
+    logger.info(f"number of frames processed: {frame_id}")
 
     if args.save_result:
         res_file = osp.join(save_folder, "results.txt")
